#
# spec file for package pam_passwdqc
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pam_passwdqc
Url:            http://www.openwall.com/passwdqc/
BuildRequires:  pam-devel
Requires:       pam
Recommends:     passwdqc
Provides:       pam-modules:/%_lib/security/pam_passwdqc.so
Version:        1.3.0
Release:        lp152.3.7
Summary:        Simple Password Strength Checking Module
License:        BSD-3-Clause
Group:          System/Libraries
Source0:        www.openwall.com/passwdqc/passwdqc-%{version}.tar.gz
Source1:        baselibs.conf
Source50:       dlopen.sh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PAM (Pluggable Authentication Modules) is a system security tool that
allows system administrators to set authentication policies without
having to recompile programs that do authentication.

pam_passwdqc is a simple password strength checking module forPAM-aware
password changing programs. In addition to checking regular passwords,
it offers support for passphrases and can provide randomly generated
ones.

%package -n libpasswdqc0
Summary:        A Simple Password Strength Checking Library
Group:          System/Libraries

%description -n libpasswdqc0
libpasswdqc is a simple password strength checking library. 
In addition to checking regular passwords, it offers support for passphrases 
and can provide randomly generated ones.

%package -n passwdqc-devel
Summary:        Useful collection of routines for C and C++ programming
Group:          Development/Libraries/C and C++
Requires:       libpasswdqc0 = %{version}

%description -n passwdqc-devel
libpasswdqc is a simple password strength checking library.
In addition to checking regular passwords, it offers support for passphrases
and can provide randomly generated ones.


%package -n passwdqc
Summary:        Tools for Password Checking and Generation
Group:          Productivity/Networking/Diagnostic

%description -n passwdqc
The pwqcheck program checks passphrase quality using the libpasswdqc library.
The pwqgen program generates a random passphrase using the libpasswdqc library.


%prep
%setup -n passwdqc-%{version}

%build
EXTRA_CFLAGS="-fno-strict-aliasing"
# ia64 is noexecstack by default
%ifnarch ia64
    EXTRA_CFLAGS="$EXTRA_CFLAGS -Wa,--noexecstack"
%endif
make CFLAGS="$RPM_OPT_FLAGS $EXTRA_CFLAGS -fPIC -DHAVE_SHADOW -DLINUX_PAM" \
     SHARED_LIBDIR="/%{_lib}" \
     DEVEL_LIBDIR="/usr/%{_lib}" \
     SECUREDIR="/%{_lib}/security"

%install
make DESTDIR=$RPM_BUILD_ROOT SHARED_LIBDIR="/%{_lib}" DEVEL_LIBDIR="/%{_libdir}" SECUREDIR="/%{_lib}/security" install

%check
# Check for module problems.  Specifically, check that every module we just
# installed can actually be loaded by a minimal PAM-aware application.
export LD_LIBRARY_PATH="$RPM_BUILD_ROOT/%{_lib}/"
for module in $RPM_BUILD_ROOT/%{_lib}/security/pam*.so ; do
   if ! sh $RPM_SOURCE_DIR/dlopen.sh -lpam -ldl ${module} ; then
      exit 1
   fi
done

%post -n libpasswdqc0 -p /sbin/ldconfig

%postun -n libpasswdqc0 -p /sbin/ldconfig

%files 
%defattr(-,root,root,755)
%attr(755,root,root) /%{_lib}/security/pam_*.so
%attr(644,root,root) %doc %{_mandir}/man8/pam_*.8.*

%files -n libpasswdqc0
%defattr(-,root,root)
/%{_lib}/libpasswdqc*.so.*

%files -n passwdqc-devel
%defattr(-,root,root)
%{_libdir}/libpasswdqc*.so
%{_includedir}/*

%files -n passwdqc
%defattr(-,root,root)
%attr(644,root,root) %doc %{_mandir}/man1/*
%attr(644,root,root) %doc %{_mandir}/man5/*
%doc INTERNALS LICENSE PLATFORMS README 
%config(noreplace) %{_sysconfdir}/*.conf
%{_bindir}/*

%changelog
* Sun Mar  8 2015 p.drouand@gmail.com
- Update to version 1.3.0
  * Detection of common character sequences has been improved.  This has
    reduced the number of passing passwords for RockYou top 100k from
    35 to 18, and for RockYou top 1M from 2333 to 2273 (all of these are
    with passwdqc's default policy).  I also tested on lists of cracked and
    not cracked passwords and reviewed the results manually to ensure
    there's no significant increase in false positives.
  * Generation of random passphrases with non-default settings has been
    improved: case toggling has been made optional, possible use of trailing
    single characters has been added, words are now separated with dashes
    when different separator characters are not in use, and the range of
    possible bit sizes of generated passphrases has been expanded (now it is
    24 to 85 bits for the programs, and 24 to 136 bits for the API).
    The code has been made more robust: possible NULL pointer returns from
    crypt(3) are handled correctly, all pre-initialized arrays and structs
    are declared as "const", greater use of cpp macros for integer constants
    and some source code comments were added (mostly in passwdqc_random.c).
  * Darwin (Mac OS X) support has been added to the Makefile
  * pwqcheck.php, a PHP wrapper function around the pwqcheck program, has
    been added.
- Use download Url as source
- Remove redundant %%clean section
* Tue Feb 21 2012 mc@suse.de
- update to version 1.2.2
- When matching against the reversed new password, always pass the
  original non-reversed new password (possibly with a substring
  removed) into is_simple(), but remove or check the correct
  substring in is_based() considering that the matching is possibly
  being done against the reversed password.
- New command-line options for pwqcheck: -1 and -2 for reading just
  1 and just 2 lines from stdin, respectively (instead of reading 3
  lines, which is the default), --multi for checking multiple
  passphrases at once (until EOF).
- With randomly-generated passphrases, encode more entropy per
  separator character (by increasing the number of different
  separators from 8 to 16) and per word (by altering the case of
  the first letter of each word), which increases the default
  generated passphrase size from 42 to 47 bits.
- Substring matching has been enhanced to partially discount rather
  than fully remove weak substrings, support leetspeak, and detect
  some common sequences of characters (sequential digits, letters in
  alphabetical order, adjacent keys on a QWERTY keyboard).
- Detect and allow passphrases with non-ASCII characters in the words.
- A number of optimizations have been made resulting in significant
  speedup of passwdqc_check() on real-world passwords.
* Wed Apr  7 2010 ro@suse.de
- fix baselibs.conf (package is called libpasswdqc0)
* Thu Mar  4 2010 mc@suse.de
- update to version 1.1.4
  * new library for password checking
  * tools for password checking and password generation
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Jun 24 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 mc@suse.de
- update to version 1.0.5
  - Replaced the separator characters with some of those defined by RFC 3986
    as being safe within "userinfo" part of URLs without encoding.
  - Reduced the default value for the N2 parameter to min=... (the minimum
    length for passphrases) from 12 to 11.
  - Corrected the potentially misleading description of N2 (Debian bug #310595).
  - Applied minor grammar and style corrections to the documentation, a
    pam_passwdqc message, and source code comments.
  - Changed Makefile to pass list of libraries to linker after regular
    object files, to fix build with -Wl,--as-needed.
  - Fixed potential memory leak in conversation wrapper.
  - Restricted list of global symbols exported by the PAM module
    to standard set of six pam_sm_* functions.
* Thu Aug 10 2006 mc@suse.de
- version 1.0.2 branched from pam-modules
